@@ -417,7 +417,7 @@ class OmniSpectrum():
     def any_angle_spectrum(self):
         if (not os.path.exists(self.path.split('.')[-2] + '_a.jpg')):
             for i in tqdm(range(0, 181)):
-                OmniSpectrum.spect(i)
+                self.spect(i)
 #                 self.pool.apply_async(OmniSpectrum.spect, (new_a, t, self.period, i, self.value_a, self.value_v, self.value_u,), error_callback=errprint)
 #             self.pool.close()
 #             self.pool.join()
